Class: Google::Apis::YoutubereportingV1::Job
- Inherits:
-
Object
- Object
- Google::Apis::YoutubereportingV1::Job
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/youtubereporting_v1/classes.rb,
lib/google/apis/youtubereporting_v1/representations.rb,
lib/google/apis/youtubereporting_v1/representations.rb
Overview
A job creating reports of a specific type.
Instance Attribute Summary collapse
-
#create_time ⇒ String
The creation date/time of the job.
-
#expire_time ⇒ String
The date/time when this job will expire/expired.
-
#id ⇒ String
The server-generated ID of the job (max. 40 characters).
-
#name ⇒ String
The name of the job (max. 100 characters).
-
#report_type_id ⇒ String
The type of reports this job creates.
-
#system_managed ⇒ Boolean
(also: #system_managed?)
True if this a system-managed job that cannot be modified by the user; otherwise false.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Job
constructor
A new instance of Job.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Job
Returns a new instance of Job.
688 689 690 |
# File 'lib/google/apis/youtubereporting_v1/classes.rb', line 688 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
The creation date/time of the job.
Corresponds to the JSON property createTime
658 659 660 |
# File 'lib/google/apis/youtubereporting_v1/classes.rb', line 658 def create_time @create_time end |
#expire_time ⇒ String
The date/time when this job will expire/expired. After a job expired, no new
reports are generated.
Corresponds to the JSON property expireTime
664 665 666 |
# File 'lib/google/apis/youtubereporting_v1/classes.rb', line 664 def expire_time @expire_time end |
#id ⇒ String
The server-generated ID of the job (max. 40 characters).
Corresponds to the JSON property id
669 670 671 |
# File 'lib/google/apis/youtubereporting_v1/classes.rb', line 669 def id @id end |
#name ⇒ String
The name of the job (max. 100 characters).
Corresponds to the JSON property name
674 675 676 |
# File 'lib/google/apis/youtubereporting_v1/classes.rb', line 674 def name @name end |
#report_type_id ⇒ String
The type of reports this job creates. Corresponds to the ID of a ReportType.
Corresponds to the JSON property reportTypeId
679 680 681 |
# File 'lib/google/apis/youtubereporting_v1/classes.rb', line 679 def report_type_id @report_type_id end |
#system_managed ⇒ Boolean Also known as: system_managed?
True if this a system-managed job that cannot be modified by the user;
otherwise false.
Corresponds to the JSON property systemManaged
685 686 687 |
# File 'lib/google/apis/youtubereporting_v1/classes.rb', line 685 def system_managed @system_managed end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
693 694 695 696 697 698 699 700 |
# File 'lib/google/apis/youtubereporting_v1/classes.rb', line 693 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @expire_time = args[:expire_time] if args.key?(:expire_time) @id = args[:id] if args.key?(:id) @name = args[:name] if args.key?(:name) @report_type_id = args[:report_type_id] if args.key?(:report_type_id) @system_managed = args[:system_managed] if args.key?(:system_managed) end |