Class: Google::Apis::YoutubereportingV1::Report

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/youtubereporting_v1/classes.rb,
lib/google/apis/youtubereporting_v1/representations.rb,
lib/google/apis/youtubereporting_v1/representations.rb

Overview

A report's metadata including the URL from which the report itself can be downloaded.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Report

Returns a new instance of Report.



819
820
821
# File 'lib/google/apis/youtubereporting_v1/classes.rb', line 819

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

The date/time when this report was created. Corresponds to the JSON property createTime

Returns:

  • (String)


785
786
787
# File 'lib/google/apis/youtubereporting_v1/classes.rb', line 785

def create_time
  @create_time
end

#download_urlString

The URL from which the report can be downloaded (max. 1000 characters). Corresponds to the JSON property downloadUrl

Returns:

  • (String)


790
791
792
# File 'lib/google/apis/youtubereporting_v1/classes.rb', line 790

def download_url
  @download_url
end

#end_timeString

The end of the time period that the report instance covers. The value is exclusive. Corresponds to the JSON property endTime

Returns:

  • (String)


796
797
798
# File 'lib/google/apis/youtubereporting_v1/classes.rb', line 796

def end_time
  @end_time
end

#idString

The server-generated ID of the report. Corresponds to the JSON property id

Returns:

  • (String)


801
802
803
# File 'lib/google/apis/youtubereporting_v1/classes.rb', line 801

def id
  @id
end

#job_expire_timeString

The date/time when the job this report belongs to will expire/expired. Corresponds to the JSON property jobExpireTime

Returns:

  • (String)


806
807
808
# File 'lib/google/apis/youtubereporting_v1/classes.rb', line 806

def job_expire_time
  @job_expire_time
end

#job_idString

The ID of the job that created this report. Corresponds to the JSON property jobId

Returns:

  • (String)


811
812
813
# File 'lib/google/apis/youtubereporting_v1/classes.rb', line 811

def job_id
  @job_id
end

#start_timeString

The start of the time period that the report instance covers. The value is inclusive. Corresponds to the JSON property startTime

Returns:

  • (String)


817
818
819
# File 'lib/google/apis/youtubereporting_v1/classes.rb', line 817

def start_time
  @start_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



824
825
826
827
828
829
830
831
832
# File 'lib/google/apis/youtubereporting_v1/classes.rb', line 824

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @download_url = args[:download_url] if args.key?(:download_url)
  @end_time = args[:end_time] if args.key?(:end_time)
  @id = args[:id] if args.key?(:id)
  @job_expire_time = args[:job_expire_time] if args.key?(:job_expire_time)
  @job_id = args[:job_id] if args.key?(:job_id)
  @start_time = args[:start_time] if args.key?(:start_time)
end